@@ -1,4 +1,9 @@
-from typing import Any, Dict, Literal, Optional, TypedDict, Union
+from typing import Any, Dict, Optional, Union
+
+try:
+    from typing import TypedDict
+except Exception:
+    from mypy_extensions import TypedDict
 
 
 class ProxiedBucketNames(TypedDict):
@@ -7,10 +12,24 @@ class ProxiedBucketNames(TypedDict):
     staff: Optional[str]
 
 
-class BackblazeB2StorageOptions(TypedDict):
-    """Configuration options. Literals indicate defaults"""
+class DjangoCacheAccountInfoConfig(TypedDict):
+    type: str  # only "django-cache" is valid
+    cache: str
 
-    realm: Literal["production"]
+
+class InMemoryAccountInfoConfig(TypedDict):
+    type: str  # only "memory" is valid
+
+
+class SqliteAccountInfoConfig(TypedDict):
+    type: str  # only "sqlite" is valid
+    databasePath: str
+
+
+class BackblazeB2StorageOptions(TypedDict):
+    """Configuration options."""
+
+    realm: str  # default "production"
     application_key_id: str
     application_key: str
     bucket: str
@@ -21,13 +40,14 @@ class BackblazeB2StorageOptions(TypedDict):
     nonExistentBucketDetails: Optional[Dict[str, Union[str, Dict[str, Any]]]]
     defaultFileInfo: Dict[str, Any]
     specificBucketNames: ProxiedBucketNames
+    accountInfo: Optional[Union[DjangoCacheAccountInfoConfig, InMemoryAccountInfoConfig, SqliteAccountInfoConfig]]
 
 
 def getDefaultB2StorageOptions() -> BackblazeB2StorageOptions:
     return {
         "realm": "production",
-        "application_key_id": "---",
-        "application_key": "---",
+        "application_key_id": "you must set this value yourself",
+        "application_key": "you must set this value yourself",
         "bucket": "django",
         "authorizeOnInit": True,
         "validateOnInit": True,
@@ -35,4 +55,5 @@ def getDefaultB2StorageOptions() -> BackblazeB2StorageOptions:
         "nonExistentBucketDetails": None,
         "defaultFileInfo": {},
         "specificBucketNames": {"public": None, "loggedIn": None, "staff": None},
+        "accountInfo": {"type": "django-cache", "cache": "django-backblaze-b2"},
     }
